% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distributions.R
\name{distributions}
\alias{distributions}
\alias{NegBin}
\alias{Poisson}
\alias{Bernoulli}
\alias{Binomial}
\alias{BetaBinomial}
\alias{ZIP}
\alias{ZINB}
\alias{ZIB}
\alias{ZIBB}
\title{Wrappers to random number generators for use with coenocliner}
\usage{
NegBin(n, mu, alpha)

Poisson(n, mu)

Bernoulli(n, mu)

Binomial(n, mu, size)

BetaBinomial(n, mu, size, theta)

ZIP(n, mu, zprobs)

ZINB(n, mu, alpha, zprobs)

ZIB(n, mu, size, zprobs)

ZIBB(n, mu, size, theta, zprobs)
}
\arguments{
\item{n}{the number of random draws, equal to number of species times the number of gradient locations.}

\item{mu}{the mean or expectation of the distribution. For \code{Bernoulli}, \code{Binomial}, and \code{BetaBinomial()} this is the probability of occurrence as given by the response function.}

\item{alpha}{numeric; dispersion parameter for the negative binomial distribution. May be a vector of length \code{length(mu)}. The NB2 parametrization of the negative binomial is used here, in which \eqn{\alpha} is positively related to the amount of extra dispersion in the simulated data. As such, where \eqn{\alpha = 0}, we would have a Poisson distribution. \code{alpha} can be supplied a value of \code{0}, in which case \code{NegBin} and \code{ZINB} return random draws from the Poisson or zero-inflated Poisson distributions, respectively. Negative values of \code{alpha} are not allowed and will generate an error.}

\item{size}{numeric; binomial denominator, the total number of individuals counted for example}

\item{theta}{numeric; a positive \emph{inverse} overdispersion parameter for the Beta-Binomial distribution. Low values give high overdispersion. The variance is  \code{size*mu*(1-mu)*(1+(size-1)/(theta+1))} (Bolker, 2008)}

\item{zprobs}{numeric; zero-inflation parameter giving the proportion of extraneous zeros. Must be in range \eqn{0 \dots 1}{0 to 1}.}
}
\value{
a vector of random draws from the stated distribution.
}
\description{
These functions are simple wrappers around existing random number generators in R to provide stochastic count data for simulated species.
}
\references{
Bolker, B.M. (2008) \emph{Ecological Models and Data
in R.} Princeton University Press.
}
\author{
Gavin L. Simpson
}
\keyword{distribution}
